@@ -49,6 +49,7 @@ getObject = {
                       'vlanNumber': 23,
                       'id': 1}],
     'dedicatedHost': {'id': 37401},
+    'transientGuestFlag': False,
     'operatingSystem': {
         'passwords': [{'username': 'user', 'password': 'pass'}],
         'softwareLicense': {
@@ -75,6 +76,17 @@ getCreateObjectOptions = {
                 }
             }
         },
+        {
+            'flavor': {
+                'keyName': 'B1_1X2X25_TRANSIENT'
+            },
+            'template': {
+                'supplementalCreateObjectOptions': {
+                    'flavorKeyName': 'B1_1X2X25_TRANSIENT'
+                },
+                'transientGuestFlag': True
+            }
+        },
         {
             'flavor': {
                 'keyName': 'B1_1X2X100'
@@ -628,3 +640,33 @@ DEDICATED_GET_UPGRADE_ITEM_PRICES = [
 ]
 
 getMetricTrackingObjectId = 1000
+
+
+getBandwidthAllotmentDetail = {
+    'allocationId': 25465663,
+    'bandwidthAllotmentId': 138442,
+    'effectiveDate': '2019-04-03T23:00:00-06:00',
+    'endEffectiveDate': None,
+    'id': 25888247,
+    'serviceProviderId': 1,
+    'allocation': {
+        'amount': '250'
+    }
+}
+
+getBillingCycleBandwidthUsage = [
+    {
+        'amountIn': '.448',
+        'amountOut': '.52157',
+        'type': {
+            'alias': 'PUBLIC_SERVER_BW'
+        }
+    },
+    {
+        'amountIn': '.03842',
+        'amountOut': '.01822',
+        'type': {
+            'alias': 'PRIVATE_SERVER_BW'
+        }
+    }
+]
