@@ -6,6 +6,7 @@
     :license: MIT, see LICENSE for more details.
 """
 
+from SoftLayer import exceptions
 from SoftLayer import utils
 
 IMAGE_MASK = ('id,accountId,name,globalIdentifier,blockDevices,parentId,'
@@ -121,8 +122,8 @@ class ImageManager(utils.IdentifierMixin, object):
         return bool(name or note or tag)
 
     def import_image_from_uri(self, name, uri, os_code=None, note=None,
-                              ibm_api_key=None, root_key_id=None,
-                              wrapped_dek=None, kp_id=None, cloud_init=False,
+                              ibm_api_key=None, root_key_crn=None,
+                              wrapped_dek=None, cloud_init=False,
                               byol=False, is_encrypted=False):
         """Import a new image from object storage.
 
@@ -136,11 +137,14 @@ class ImageManager(utils.IdentifierMixin, object):
         :param string os_code: The reference code of the operating system
         :param string note: Note to add to the image
         :param string ibm_api_key: Ibm Api Key needed to communicate with ICOS
-            and Key Protect
-        :param string root_key_id: ID of the root key in Key Protect
+            and your KMS
+        :param string root_key_crn: CRN of the root key in your KMS. Go to your
+            KMS (Key Protect or Hyper Protect) provider to get the CRN for your
+            root key.  An example CRN:
+            crn:v1:bluemix:public:hs-crypto:us-south:acctID:serviceID:key:keyID'
+            Used only when is_encrypted is True.
         :param string wrapped_dek: Wrapped Data Encryption Key provided by
-            IBM KeyProtect
-        :param string kp_id: ID of the IBM Key Protect Instance
+            your KMS. Used only when is_encrypted is True.
         :param boolean cloud_init: Specifies if image is cloud-init
         :param boolean byol: Specifies if image is bring your own license
         :param boolean is_encrypted: Specifies if image is encrypted
@@ -152,9 +156,8 @@ class ImageManager(utils.IdentifierMixin, object):
                 'operatingSystemReferenceCode': os_code,
                 'uri': uri,
                 'ibmApiKey': ibm_api_key,
-                'rootKeyId': root_key_id,
+                'crkCrn': root_key_crn,
                 'wrappedDek': wrapped_dek,
-                'keyProtectId': kp_id,
                 'cloudInit': cloud_init,
                 'byol': byol,
                 'isEncrypted': is_encrypted
@@ -185,3 +188,52 @@ class ImageManager(utils.IdentifierMixin, object):
             }, id=image_id)
         else:
             return self.vgbdtg.copyToExternalSource({'uri': uri}, id=image_id)
+
+    def add_locations(self, image_id, location_names):
+        """Add available locations to an archive image template.
+
+        :param int image_id: The ID of the image
+        :param location_names: Locations for the Image.
+        """
+        locations = self.get_locations_list(image_id, location_names)
+        return self.vgbdtg.addLocations(locations, id=image_id)
+
+    def remove_locations(self, image_id, location_names):
+        """Remove available locations from an archive image template.
+
+        :param int image_id: The ID of the image
+        :param location_names: Locations for the Image.
+        """
+        locations = self.get_locations_list(image_id, location_names)
+        return self.vgbdtg.removeLocations(locations, id=image_id)
+
+    def get_storage_locations(self, image_id):
+        """Get available locations for public image storage.
+
+        :param int image_id: The ID of the image
+        """
+        return self.vgbdtg.getStorageLocations(id=image_id)
+
+    def get_locations_list(self, image_id, location_names):
+        """Converts a list of location names to a list of locations.
+
+        :param int image_id: The ID of the image.
+        :param list location_names: A list of location names strings.
+        :returns: A list of locations associated with the given location names in the image.
+        """
+        locations = self.get_storage_locations(image_id)
+        locations_ids = []
+        matching_location = {}
+        output_error = "Location {} does not exist for available locations for image {}"
+
+        for location_name in location_names:
+            for location in locations:
+                if location_name == location.get('name'):
+                    matching_location = location
+                    break
+            if matching_location.get('id') is None:
+                raise exceptions.SoftLayerError(output_error.format(location_name, image_id))
+
+            locations_ids.append(matching_location)
+
+        return locations_ids
