@@ -60,6 +60,7 @@ class BlockTests(testing.TestCase):
 
         self.assert_no_fail(result)
         isinstance(json.loads(result.output)['IOPs'], float)
+        self.assert_called_with('SoftLayer_Network_Storage', 'getObject', identifier=1234)
         self.assertEqual({
             'Username': 'username',
             'LUN Id': '2',
@@ -98,6 +99,26 @@ class BlockTests(testing.TestCase):
             ]
         }, json.loads(result.output))
 
+    def test_volume_detail_name_identifier(self):
+        result = self.run_command(['block', 'volume-detail', 'SL-12345'])
+        expected_filter = {
+            'iscsiNetworkStorage': {
+                'serviceResource': {
+                    'type': {
+                        'type': {'operation': '!~ ISCSI'}
+                    }
+                },
+                'storageType': {
+                    'keyName': {'operation': '*= BLOCK_STORAGE'}
+                },
+                'username': {'operation': '_= SL-12345'}
+                }
+        }
+
+        self.assert_called_with('SoftLayer_Account', 'getIscsiNetworkStorage', filter=expected_filter)
+        self.assert_called_with('SoftLayer_Network_Storage', 'getObject', identifier=100)
+        self.assert_no_fail(result)
+
     def test_volume_list(self):
         result = self.run_command(['block', 'volume-list'])
 
@@ -438,6 +459,23 @@ class BlockTests(testing.TestCase):
 
         self.assert_no_fail(result)
 
+    def test_assign_subnets_to_acl(self):
+        result = self.run_command(['block', 'subnets-assign', '12345',
+                                   '--subnet-id=12345678'])
+
+        self.assert_no_fail(result)
+
+    def test_remove_subnets_from_acl(self):
+        result = self.run_command(['block', 'subnets-remove', '12345',
+                                   '--subnet-id=12345678'])
+
+        self.assert_no_fail(result)
+
+    def test_get_subnets_in_acl(self):
+        result = self.run_command(['block', 'subnets-list', '12345'])
+
+        self.assert_no_fail(result)
+
     def test_replicant_failover(self):
         result = self.run_command(['block', 'replica-failover', '12345678',
                                    '--replicant-id=5678'])
@@ -625,7 +663,8 @@ class BlockTests(testing.TestCase):
                                       duplicate_size=250, duplicate_iops=None,
                                       duplicate_tier_level=2,
                                       duplicate_snapshot_size=20,
-                                      hourly_billing_flag=True)
+                                      hourly_billing_flag=True,
+                                      dependent_duplicate=False)
         self.assert_no_fail(result)
         self.assertEqual(result.output,
                          'Order #24602 placed successfully!\n'
@@ -665,3 +704,25 @@ class BlockTests(testing.TestCase):
     def test_set_password(self):
         result = self.run_command(['block', 'access-password', '1234', '--password=AAAAA'])
         self.assert_no_fail(result)
+
+    @mock.patch('SoftLayer.BlockStorageManager.list_block_volume_limit')
+    def test_volume_limit(self, list_mock):
+        list_mock.return_value = [
+            {
+                "datacenterName": "global",
+                "maximumAvailableCount": 300,
+                "provisionedCount": 100
+            }]
+
+        result = self.run_command(['block', 'volume-limits'])
+        self.assert_no_fail(result)
+
+    def test_dep_dupe_refresh(self):
+        result = self.run_command(['block', 'volume-refresh', '102', '103'])
+
+        self.assert_no_fail(result)
+
+    def test_dep_dupe_convert(self):
+        result = self.run_command(['block', 'volume-convert', '102'])
+
+        self.assert_no_fail(result)
